from django.db import models
from django.utils.translation import ugettext as _

from social.models import Entry, UserProfile


YES = 1
NO = 2
MAYBE = 3
RSVP_CHOISES = (
    (YES, _('yes')),
    (NO, _('no')),
    (MAYBE, _('maybe')),
)


class Event(models.Model):
    """Event with option registrations for attendees.

    Should be used with OpenLayers.

    """

    entry = models.OneToOneField(Entry)
    start_date = models.DateTimeField()
    end_date = models.DateTimeField()
    #location = PointField()

    def __unicode__(self):
        return u'<%s> %s - %s'%(this.id, this.start_date, this.end_date)

    @models.permalink
    def get_absolute_url(self):
        """ Returns url of edit page of this event.
        """
        return ('socialplugin-events-add', [self.id])

    class Meta(object):
        ordering = ['start_date']


class Attendee(models.Model):
    """Users that planning to attend.
    """

    event = models.ForeignKey(Event)
    user = models.ForeignKey(UserProfile)
    rsvp = models.IntegerField(choices=RSVP_CHOISES, default=1)

    def __unicode__(self):
        return u'<%s> %s -> %s'%(this.id, this.user.id, this.event.id)

    class Meta(object):
        ordering = ['event', 'rsvp']
