from django.template import RequestContext
from django.shortcuts import get_object_or_404, redirect
from annoying.decorators import render_to

from social.models import Entry, Plugin
from social.forms import EntryForm

from models import Event
from forms import EventForm


@render_to('socialplugin_events/add.html')
def add_event(request, event_id=None):
    """Add new event or edit existing.
    """
    
    if event_id:
        event = get_object_or_404(Event, id=event_id)
        entry = event.entry
        new_event = False               # Editing existing event.
    else:
        entry = Entry()
        event = Event()
        new_event = True                # Adding new event.

    errors = False                      # If no errors found.

    if request.method == 'POST':
        event_form = EventForm(request.POST, instance=event)
        entry_form = EntryForm(request.POST, instance=entry)
        if event_form.is_valid() and entry_form.is_valid():
            entry = entry_form.save(commit=False)
            event = event_form.save(commit=False)
            if new_event:
                entry.plugin = Plugin.objects.get_or_create(
                        plugin="socialplugins-events")[0]
                                        # FIXME: Must be normal plugin!
                entry.author = request.user.get_profile()
                event.entry = entry
            entry.save()
            event.save()
            return redirect(
                    'socialplugin-events-display',
                    event_id=event.id)
        else:
            errors = True
    else:
        event_form = EventForm(instance=event)
        entry_form = EntryForm(instance=entry)

    return { 
            'event_form': event_form, 
            'entry_form': entry_form,
            'errors': errors,
            }
